---
slug: /drop-trigger
---

# DROP TRIGGER

The `DROP TRIGGER` statement is used to delete a trigger.

The syntax for the `DROP TRIGGER` statement is as follows:

```sql
DROP TRIGGER [IF EXISTS] [schema_name.]trigger_name
```

The schema (database) name is optional. If you omit `schema_name`, the trigger will be dropped from the default schema. The `DROP TRIGGER` statement requires the `TRIGGER` privilege on the table associated with the trigger.

Using the `IF EXISTS` clause prevents an error from occurring and generates a `NOTE` for non-existent triggers.

If a table is dropped, its triggers are also dropped.

Here is an example of the `DROP TRIGGER` statement:

```sql
DROP TRIGGER IF EXISTS test_trg;
Query OK, 0 rows affected
```